<?php

namespace Litecms\Location\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Location\Actions\CityAction;
use Litecms\Location\Http\Requests\CityActionRequest;
use Litecms\Location\Http\Resources\CityResource;
use Litecms\Location\Models\City;

/**
 * Admin web controller class.
 */
class CityActionController extends BaseController
{

    /**
     * Action controller function for city.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CityActionRequest $request, City $city, $action)
    {
        try {
            $city = CityAction::run($request, $city, $action);

            $data = new CityResource($city);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('location::city.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('location/city/' . $city->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('location/city/' . $city->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
