<?php

namespace Litecms\Location\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Location\Actions\CountryAction;
use Litecms\Location\Http\Requests\CountryActionRequest;
use Litecms\Location\Http\Resources\CountryResource;
use Litecms\Location\Models\Country;

/**
 * Admin web controller class.
 */
class CountryActionController extends BaseController
{

    /**
     * Action controller function for country.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CountryActionRequest $request, Country $country, $action)
    {
        try {
            $country = CountryAction::run($request, $country, $action);

            $data = new CountryResource($country);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('location::country.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('location/country/' . $country->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('location/country/' . $country->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
