<?php

namespace Litecms\Location\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Location\Http\Requests\CountryActionsRequest;
use Litecms\Location\Models\CountryActions;

/**
 * Admin web controller class.
 */
class CountryActionsController extends BaseController
{

    /**
     * Action controller function for country.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CountryActionsRequest $request, $action)
    {
        try {
            $country = CountryActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('location::country.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('location/country/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('location/country/' . $action))
                ->redirect();
        }
    }
}
