<?php

namespace Litecms\Location\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Location\Actions\LocationAction;
use Litecms\Location\Http\Requests\LocationActionRequest;
use Litecms\Location\Http\Resources\LocationResource;
use Litecms\Location\Models\Location;

/**
 * Admin web controller class.
 */
class LocationActionController extends BaseController
{

    /**
     * Action controller function for location.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LocationActionRequest $request, Location $location, $action)
    {
        try {
            $location = LocationAction::run($request, $location, $action);

            $data = new LocationResource($location);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('location::location.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('location/location/' . $location->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('location/location/' . $location->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
