<?php

namespace Litecms\Location\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Location\Http\Requests\LocationActionsRequest;
use Litecms\Location\Models\LocationActions;

/**
 * Admin web controller class.
 */
class LocationActionsController extends BaseController
{

    /**
     * Action controller function for location.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LocationActionsRequest $request, $action)
    {
        try {
            $location = LocationActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('location::location.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('location/location/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('location/location/' . $action))
                ->redirect();
        }
    }
}
