<?php

namespace Litecms\Location\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Location\Http\Requests\PropertyActionsRequest;
use Litecms\Location\Models\PropertyActions;

/**
 * Admin web controller class.
 */
class PropertyActionsController extends BaseController
{

    /**
     * Action controller function for property.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PropertyActionsRequest $request, $action)
    {
        try {
            $property = PropertyActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('location::property.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('location/property/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('location/property/' . $action))
                ->redirect();
        }
    }
}
