<?php

namespace Litecms\Location\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Location\Actions\SublocationAction;
use Litecms\Location\Http\Requests\SublocationActionRequest;
use Litecms\Location\Http\Resources\SublocationResource;
use Litecms\Location\Models\Sublocation;

/**
 * Admin web controller class.
 */
class SublocationActionController extends BaseController
{

    /**
     * Action controller function for sublocation.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(SublocationActionRequest $request, Sublocation $sublocation, $action)
    {
        try {
            $sublocation = SublocationAction::run($request, $sublocation, $action);

            $data = new SublocationResource($sublocation);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('location::sublocation.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('location/sublocation/' . $sublocation->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('location/sublocation/' . $sublocation->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
