<?php

namespace Litecms\Location\Policies;

use Litecms\Location\Models\Country;
use Litepie\User\Interfaces\UserPolicyInterface;

trait CountryAction
{

    /**
     * Determine if the given user can approve the given country.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function copy(UserPolicyInterface $authUser, Country $country)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('location.country.action.copy')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given country.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    function empty(UserPolicyInterface $authUser, Country $country) {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('location.country.action.empty')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given country.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function transfer(UserPolicyInterface $authUser, Country $country)
    {
        if ($authUser->is($this->model->owner())) {
            return true;
        }

        if ($authUser->canDo('location.country.action.transfer')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given country.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function delete(UserPolicyInterface $authUser, Country $country)
    {


        if ($authUser->canDo('location.country.action.delete')) {
            return true;
        }

        return false;
    }


}
