<?php

namespace Litecms\Location\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Location\Models\Country;

class CountryPolicy
{

    use CountryAction;

    /**
     * Determine if the given user can view the country.
     *
     * @param UserPolicyInterface $authUser
     * @param Country $country
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Country $country)
    {
        if ($authUser->canDo('location.country.view') && $authUser->isAdmin()) {
            return true;
        }

        return $country->user_id == user_id() && $country->user_type == user_type();
    }

    /**
     * Determine if the given user can create a country.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('location.country.create');
    }

    /**
     * Determine if the given user can update the given country.
     *
     * @param UserPolicyInterface $authUser
     * @param Country $country
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Country $country)
    {
        if ($authUser->canDo('location.country.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $country->user_id == user_id() && $country->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given country.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Country $country)
    {
        return $country->user_id == user_id() && $country->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given country.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Country $country)
    {
        if ($authUser->canDo('location.country.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given country.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Country $country)
    {
        if ($authUser->canDo('location.country.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
