<?php

namespace Litecms\Location\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Location\Models\Sublocation;

class SublocationPolicy
{

    use SublocationAction;

    /**
     * Determine if the given user can view the sublocation.
     *
     * @param UserPolicyInterface $authUser
     * @param Sublocation $sublocation
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Sublocation $sublocation)
    {
        if ($authUser->canDo('location.sublocation.view') && $authUser->isAdmin()) {
            return true;
        }

        return $sublocation->user_id == user_id() && $sublocation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sublocation.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('location.sublocation.create');
    }

    /**
     * Determine if the given user can update the given sublocation.
     *
     * @param UserPolicyInterface $authUser
     * @param Sublocation $sublocation
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Sublocation $sublocation)
    {
        if ($authUser->canDo('location.sublocation.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $sublocation->user_id == user_id() && $sublocation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sublocation.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Sublocation $sublocation)
    {
        return $sublocation->user_id == user_id() && $sublocation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sublocation.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Sublocation $sublocation)
    {
        if ($authUser->canDo('location.sublocation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sublocation.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Sublocation $sublocation)
    {
        if ($authUser->canDo('location.sublocation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
