<?php

namespace Litecms\Location\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Location\Locations;

class LocationServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'location');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'location');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Litecms\Location\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Location\Providers\RouteServiceProvider::class);
        $this->app->register(\Litecms\Location\Providers\ActionServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.location', function($app)
        {
            return $this->app->make(Locations::class);
        });
    }

    /**
     * Merges user's and location's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.location'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/sublocation.php', 'litecms.location.sublocation'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/property.php', 'litecms.location.property'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/location.php', 'litecms.location.location'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/country.php', 'litecms.location.country'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/city.php', 'litecms.location.city'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.location'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('litecms/location')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/location')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/location')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
