<?php

namespace Litecms\Location\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Litecms\Location\Models\Sublocation;
use Litecms\Location\Models\Property;
use Litecms\Location\Models\Location;
use Litecms\Location\Models\Country;
use Litecms\Location\Models\City;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\Location\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/location/sublocation/*')) {
            Route::bind('sublocation', function ($sublocation) {
                return Sublocation::findorNew($sublocation);
            });
        }
        if (Request::is('*/location/property/*')) {
            Route::bind('property', function ($property) {
                return Property::findorNew($property);
            });
        }
        if (Request::is('*/location/location/*')) {
            Route::bind('location', function ($location) {
                return Location::findorNew($location);
            });
        }
        if (Request::is('*/location/country/*')) {
            Route::bind('country', function ($country) {
                return Country::findorNew($country);
            });
        }
        if (Request::is('*/location/city/*')) {
            Route::bind('city', function ($city) {
                return City::findorNew($city);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
